"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.$ = void 0;
var react_1 = require("react");
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
var shared_1 = require("./shared");
// TODO: add better TS support
/**
 * <$> fragment will subscribe to it's Observable children and display
 * it's emissions along with regular children
 *
 * e.g.
 *
 * ```jsx
 * function App(){
 *   return <$>{ timer(0, 1000) }</$>    // 0, 1, 2, 3, ...
 * }
 * ```
 */
function $(props) {
    var children = props === null || props === void 0 ? void 0 : props.children;
    // store children
    var _a = react_1.useState(null), cn = _a[0], setCn = _a[1];
    var _b = react_1.useState(null), error = _b[0], setError = _b[1];
    var destroy$ = shared_1.useDestroyObservable();
    react_1.useEffect(function () {
        // array of children, one of em might be observable
        if (Array.isArray(children)) {
            setCn(
            // recursively create another $ for Observables
            children.map(function (c) { return (rxjs_1.isObservable(c) ? react_1.createElement($, null, c) : c); }));
            return;
        }
        // child is a single observable
        if (rxjs_1.isObservable(children)) {
            var sub_1 = children.pipe(operators_1.takeUntil(destroy$)).subscribe({
                next: setCn,
                error: function (error) {
                    // wrap error in an object to be safe in case the error is nullish
                    setError({ error: error });
                },
            });
            return function () { return sub_1.unsubscribe(); };
        }
        // child is a regular child, like you and me
        setCn(children);
    }, [children]);
    // raise an error if Observable failed
    if (error) {
        throw error.error;
    }
    // NOTE: array children are rendered inside <></> fragment
    //       while regular children are rendered directly as children of <$>,
    //       without additional <>
    //       this might be an unwanted behavior difference
    // TODO: research for real-life effects of this difference
    return Array.isArray(cn) ? react_1.createElement.apply(void 0, __spreadArrays([react_1.Fragment, null], cn)) : cn;
}
exports.$ = $;
